Fri
25
May 2007
Na dobry koniec dnia wyniki pomiaru wydajności moich nowych funkcji do konwersji między liczbą a łańcuchem - porównane z funkcjami systemowymi (plus konwersje do std::string, bo takich łańcuchów wszędzie używam i takich używają te moje funkcje). Wyniki w mikrosekundach na pojedyncze wywołanie, już podzielone przez liczbę wykonanych iteracji.
- DEBUG
- int > string
itoa : 0.244895 us
IntToStr (stary) : 3.20974 us
IntToStr (nowy) : 0.659205 us
- string > int
atoi : 0.270027 us
StrToInt : 0.391424 us
- RELEASE
- int > string
itoa : 0.137373 us
IntToStr (stary) : 0.225465 us
IntToStr (nowy) : 0.134297 us
- string > int
atoi : 0.0785857 us
StrToInt : 0.0589072 us
Comments | #c++ #algorithms Share